@@ -1,4 +1,9 @@
-class ReferenceError(RuntimeError):
+class OAPIError(Exception):
+
+    pass
+
+
+class ReferenceError(OAPIError):
 
     pass
 
@@ -11,3 +16,8 @@ class ReferenceLoopError(ReferenceError):
 class ReferencePointerError(ReferenceError):
 
     pass
+
+
+class DuplicateClassNameError(OAPIError):
+
+    pass
